@@ -247,7 +247,7 @@ impl Config {
     }
 
     pub fn get_tcolor(line: &str) -> Style {
-        let (foreground, background) = line.split_at(line.to_lowercase().find("on ").unwrap_or_else(|| line.len()));
+        let (foreground, background) = line.split_at(line.to_lowercase().find("on ").unwrap_or(line.len()));
         let (mut foreground, mut background) = (String::from(foreground), String::from(background));
         background = background.replace("on ", "");
         let mut modifiers = Modifier::empty();
